@@ -44,6 +44,7 @@ __protobuf__ = proto.module(
         "ListProcessorTypesResponse",
         "ListProcessorsRequest",
         "ListProcessorsResponse",
+        "GetProcessorTypeRequest",
         "GetProcessorRequest",
         "GetProcessorVersionRequest",
         "ListProcessorVersionsRequest",
@@ -625,6 +626,20 @@ class ListProcessorsResponse(proto.Message):
     )
 
 
+class GetProcessorTypeRequest(proto.Message):
+    r"""Request message for get processor.
+
+    Attributes:
+        name (str):
+            Required. The processor type resource name.
+    """
+
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+
+
 class GetProcessorRequest(proto.Message):
     r"""Request message for get processor.
 
