@@ -66,7 +66,7 @@ class DocumentSchema(proto.Message):
                 following naming conventions:
 
                 -  *use ``snake_casing``*
-                -  name matching is case-insensitive
+                -  name matching is case-sensitive
                 -  Maximum 64 characters.
                 -  Must start with a letter.
                 -  Allowed characters: ASCII letters ``[a-z0-9_-]``. (For
