@@ -13,9 +13,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
 from google.protobuf import timestamp_pb2  # type: ignore
 import proto  # type: ignore
 
+from google.cloud.documentai_v1beta3.types import document_schema as gcd_document_schema
+
 __protobuf__ = proto.module(
     package="google.cloud.documentai.v1beta3",
     manifest={
@@ -39,6 +43,9 @@ class ProcessorVersion(proto.Message):
             ``projects/{project}/locations/{location}/processors/{processor}/processorVersions/{processor_version}``
         display_name (str):
             The display name of the processor version.
+        document_schema (google.cloud.documentai_v1beta3.types.DocumentSchema):
+            The schema of the processor version.
+            Describes the output.
         state (google.cloud.documentai_v1beta3.types.ProcessorVersion.State):
             The state of the processor version.
         create_time (google.protobuf.timestamp_pb2.Timestamp):
@@ -80,47 +87,52 @@ class ProcessorVersion(proto.Message):
                 used as a replacement.
         """
 
-        deprecation_time = proto.Field(
+        deprecation_time: timestamp_pb2.Timestamp = proto.Field(
             proto.MESSAGE,
             number=1,
             message=timestamp_pb2.Timestamp,
         )
-        replacement_processor_version = proto.Field(
+        replacement_processor_version: str = proto.Field(
             proto.STRING,
             number=2,
         )
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    display_name = proto.Field(
+    display_name: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    state = proto.Field(
+    document_schema: gcd_document_schema.DocumentSchema = proto.Field(
+        proto.MESSAGE,
+        number=12,
+        message=gcd_document_schema.DocumentSchema,
+    )
+    state: State = proto.Field(
         proto.ENUM,
         number=6,
         enum=State,
     )
-    create_time = proto.Field(
+    create_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=7,
         message=timestamp_pb2.Timestamp,
     )
-    kms_key_name = proto.Field(
+    kms_key_name: str = proto.Field(
         proto.STRING,
         number=9,
     )
-    kms_key_version_name = proto.Field(
+    kms_key_version_name: str = proto.Field(
         proto.STRING,
         number=10,
     )
-    google_managed = proto.Field(
+    google_managed: bool = proto.Field(
         proto.BOOL,
         number=11,
     )
-    deprecation_info = proto.Field(
+    deprecation_info: DeprecationInfo = proto.Field(
         proto.MESSAGE,
         number=13,
         message=DeprecationInfo,
@@ -137,8 +149,9 @@ class Processor(proto.Message):
             Format:
             ``projects/{project}/locations/{location}/processors/{processor}``
         type_ (str):
-            The processor type, e.g., OCR_PROCESSOR, INVOICE_PROCESSOR,
-            etc. To get a list of processors types, see
+            The processor type, e.g., ``OCR_PROCESSOR``,
+            ``INVOICE_PROCESSOR``, etc. To get a list of processors
+            types, see
             [FetchProcessorTypes][google.cloud.documentai.v1beta3.DocumentProcessorService.FetchProcessorTypes].
         display_name (str):
             The display name of the processor.
@@ -168,37 +181,37 @@ class Processor(proto.Message):
         FAILED = 6
         DELETING = 7
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    type_ = proto.Field(
+    type_: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    display_name = proto.Field(
+    display_name: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    state = proto.Field(
+    state: State = proto.Field(
         proto.ENUM,
         number=4,
         enum=State,
     )
-    default_processor_version = proto.Field(
+    default_processor_version: str = proto.Field(
         proto.STRING,
         number=9,
     )
-    process_endpoint = proto.Field(
+    process_endpoint: str = proto.Field(
         proto.STRING,
         number=6,
     )
-    create_time = proto.Field(
+    create_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=7,
         message=timestamp_pb2.Timestamp,
     )
-    kms_key_name = proto.Field(
+    kms_key_name: str = proto.Field(
         proto.STRING,
         number=8,
     )
