@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
 from google.api import launch_stage_pb2  # type: ignore
 import proto  # type: ignore
 
@@ -31,13 +33,14 @@ class ProcessorType(proto.Message):
     Attributes:
         name (str):
             The resource name of the processor type. Format:
-            projects/{project}/processorTypes/{processor_type}
+            ``projects/{project}/processorTypes/{processor_type}``
         type_ (str):
-            The type of the processor, e.g., "invoice_parsing".
+            The processor type, e.g., ``OCR_PROCESSOR``,
+            ``INVOICE_PROCESSOR``, etc.
         category (str):
             The processor category, used by UI to group
             processor types.
-        available_locations (Sequence[google.cloud.documentai_v1beta3.types.ProcessorType.LocationInfo]):
+        available_locations (MutableSequence[google.cloud.documentai_v1beta3.types.ProcessorType.LocationInfo]):
             The locations in which this processor is
             available.
         allow_creation (bool):
@@ -47,6 +50,9 @@ class ProcessorType(proto.Message):
             access.
         launch_stage (google.api.launch_stage_pb2.LaunchStage):
             Launch stage of the processor type
+        sample_document_uris (MutableSequence[str]):
+            A set of Cloud Storage URIs of sample
+            documents for this processor.
     """
 
     class LocationInfo(proto.Message):
@@ -58,37 +64,41 @@ class ProcessorType(proto.Message):
                 The location id, currently must be one of [us, eu].
         """
 
-        location_id = proto.Field(
+        location_id: str = proto.Field(
             proto.STRING,
             number=1,
         )
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    type_ = proto.Field(
+    type_: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    category = proto.Field(
+    category: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    available_locations = proto.RepeatedField(
+    available_locations: MutableSequence[LocationInfo] = proto.RepeatedField(
         proto.MESSAGE,
         number=4,
         message=LocationInfo,
     )
-    allow_creation = proto.Field(
+    allow_creation: bool = proto.Field(
         proto.BOOL,
         number=6,
     )
-    launch_stage = proto.Field(
+    launch_stage: launch_stage_pb2.LaunchStage = proto.Field(
         proto.ENUM,
         number=8,
         enum=launch_stage_pb2.LaunchStage,
     )
+    sample_document_uris: MutableSequence[str] = proto.RepeatedField(
+        proto.STRING,
+        number=9,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
